/*
 * Copyright (c) 2012, 2019, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

/*
 * COPYRIGHT AND PERMISSION NOTICE
 *
 * Copyright (C) 1991-2016 Unicode, Inc. All rights reserved.
 * Distributed under the Terms of Use in 
 * http://www.unicode.org/copyright.html.
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of the Unicode data files and any associated documentation
 * (the "Data Files") or Unicode software and any associated documentation
 * (the "Software") to deal in the Data Files or Software
 * without restriction, including without limitation the rights to use,
 * copy, modify, merge, publish, distribute, and/or sell copies of
 * the Data Files or Software, and to permit persons to whom the Data Files
 * or Software are furnished to do so, provided that
 * (a) this copyright and permission notice appear with all copies 
 * of the Data Files or Software,
 * (b) this copyright and permission notice appear in associated 
 * documentation, and
 * (c) there is clear notice in each modified Data File or in the Software
 * as well as in the documentation associated with the Data File(s) or
 * Software that the data or software has been modified.
 *
 * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
 * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
 * WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT OF THIRD PARTY RIGHTS.
 * IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
 * NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
 * DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
 * DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
 * TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
 * PERFORMANCE OF THE DATA FILES OR SOFTWARE.
 *
 * Except as contained in this notice, the name of a copyright holder
 * shall not be used in advertising or otherwise to promote the sale,
 * use or other dealings in these Data Files or Software without prior
 * written authorization of the copyright holder.
 */

package sun.util.resources.cldr.ext;

import sun.util.resources.OpenListResourceBundle;

public class LocaleNames_to extends OpenListResourceBundle {
    @Override
    protected final Object[][] getContents() {
        final Object[][] data = new Object[][] {
            { "001", "M\u0101mani" },
            { "002", "\u02bbAfilika" },
            { "003", "\u02bbAmelika tokelau" },
            { "005", "\u02bbAmelika tonga" },
            { "009", "\u02bbOs\u0113nia" },
            { "011", "\u02bbAfilika fakahihifo" },
            { "013", "\u02bbAmelika lotoloto" },
            { "014", "\u02bbAfilika fakahahake" },
            { "015", "\u02bbAfilika fakatokelau" },
            { "017", "\u02bbAfilika lotoloto" },
            { "018", "\u02bbAfilika fakatonga" },
            { "019", "Ongo \u02bbAmelika" },
            { "021", "\u02bbAmelika fakatokelau" },
            { "029", "Kalipiane" },
            { "030", "\u02bb\u0112sia fakahahake" },
            { "034", "\u02bb\u0112sia fakatonga" },
            { "035", "\u02bb\u0112sia fakatongahahake" },
            { "039", "\u02bbEulope fakatonga" },
            { "053", "\u02bbAositel\u0113l\u0113sia" },
            { "054", "Melan\u012bsia" },
            { "057", "Potu fonua Mikolon\u012bsia" },
            { "061", "Polin\u012bsia" },
            { "142", "\u02bb\u0112sia" },
            { "143", "\u02bb\u0112sia lotoloto" },
            { "145", "\u02bb\u0112sia fakahihifo" },
            { "150", "\u02bbEulope" },
            { "151", "\u02bbEulope fakahahake" },
            { "154", "\u02bbEulope fakatokelau" },
            { "155", "\u02bbEulope fakahihifo" },
            { "419", "\u02bbAmelika fakalatina" },
            { "AC", "Motu \u02bbAsenisini" },
            { "AD", "\u02bbAnitola" },
            { "AE", "\u02bbAlepea Fakatahataha" },
            { "AF", "\u02bbAfik\u0101nisitani" },
            { "AG", "Anitikua mo Palaputa" },
            { "AI", "Anikuila" },
            { "AL", "\u02bbAlipania" },
            { "AM", "\u02bb\u0100menia" },
            { "AO", "\u02bbAngikola" },
            { "AQ", "\u02bbAnit\u0101tika" },
            { "AR", "\u02bbAsenitina" },
            { "AS", "Ha\u02bbamoa \u02bbAmelika" },
            { "AT", "\u02bbAositulia" },
            { "AU", "\u02bbAositel\u0113lia" },
            { "AW", "\u02bbAlupa" },
            { "AX", "\u02bbOtumotu \u02bbAlani" },
            { "AZ", "\u02bbAsapaisani" },
            { "BA", "Posinia mo Hesik\u014dvina" },
            { "BB", "P\u0101peitosi" },
            { "BD", "Pengil\u0101tesi" },
            { "BE", "Pelesiume" },
            { "BF", "Pekano Faso" },
            { "BG", "Pulukalia" },
            { "BH", "Paleini" },
            { "BI", "Puluniti" },
            { "BJ", "Penini" },
            { "BL", "S\u0101 Pat\u0113lemi" },
            { "BM", "P\u0113muta" },
            { "BN", "Pulunei" },
            { "BO", "Pol\u012bvia" },
            { "BQ", "Kalipiane fakah\u014dlani" },
            { "BR", "Pal\u0101sili" },
            { "BS", "Pahama" },
            { "BT", "P\u016btani" },
            { "BV", "Motu Puveti" },
            { "BW", "Potisiuana" },
            { "BY", "Pelalusi" },
            { "BZ", "Pelise" },
            { "CA", "K\u0101nata" },
            { "CC", "\u02bbOtumotu Koko" },
            { "CD", "Kongo - Kinisasa" },
            { "CF", "Lepupelika \u02bbAfilika Lotoloto" },
            { "CG", "Kongo - Palasavila" },
            { "CH", "Suisilani" },
            { "CI", "Matafonua \u02bbAivol\u012b" },
            { "CK", "\u02bbOtumotu Kuki" },
            { "CL", "Sili" },
            { "CM", "Kameluni" },
            { "CN", "Siaina" },
            { "CO", "Kolomipia" },
            { "CP", "Motu Kilipatoni" },
            { "CR", "Kosita Lika" },
            { "CU", "Kiupa" },
            { "CV", "Mui\u02bbi V\u0113te" },
            { "CW", "Kulasao" },
            { "CX", "Motu Kilisimasi" },
            { "CY", "Saipalesi" },
            { "CZ", "S\u0113kia" },
            { "DE", "Siamane" },
            { "DG", "Tieko K\u0101sia" },
            { "DJ", "Siputi" },
            { "DK", "Tenima\u02bbake" },
            { "DM", "Tominika" },
            { "DO", "Lepupelika Tominika" },
            { "DZ", "\u02bbAlisilia" },
            { "EA", "Siuta mo Melila" },
            { "EC", "\u02bbEkuetoa" },
            { "EE", "\u02bbEsit\u014dnia" },
            { "EG", "\u02bbIsipite" },
            { "EH", "Sahala fakahihifo" },
            { "ER", "\u02bbElitulia" },
            { "ES", "Sipeini" },
            { "ET", "\u02bb\u012ati\u014dpia" },
            { "EU", "\u02bbEulope fakatahataha" },
            { "EZ", "\u02bbEulope fekau\u02bbaki-pa\u02bbanga" },
            { "FI", "Finilani" },
            { "FJ", "Fisi" },
            { "FK", "\u02bbOtumotu Fokulani" },
            { "FM", "Mikolon\u012bsia" },
            { "FO", "\u02bbOtumotu Faloe" },
            { "FR", "Falanis\u0113" },
            { "GA", "Kaponi" },
            { "GB", "Pilit\u0101nia" },
            { "GD", "Kelenat\u0101" },
            { "GE", "Se\u014dsia" },
            { "GF", "Kuiana fakafalanis\u0113" },
            { "GG", "Kuenis\u012b" },
            { "GH", "Kana" },
            { "GI", "Sipal\u0101lit\u0101" },
            { "GL", "Kulinilani" },
            { "GM", "Kamipia" },
            { "GN", "Kini" },
            { "GP", "Kuatalupe" },
            { "GQ", "\u02bbEkueta Kini" },
            { "GR", "Kalisi" },
            { "GS", "\u02bbOtumotu Se\u014dsia-tonga mo Saniuisi-tonga" },
            { "GT", "Kuatamala" },
            { "GU", "Kuamu" },
            { "GW", "Kini-Pisau" },
            { "GY", "Kuiana" },
            { "HK", "Hongi Kongi SAR Siaina" },
            { "HM", "\u02bbOtumotu Heati mo Makitonali" },
            { "HN", "Honitulasi" },
            { "HR", "Kuloisia" },
            { "HT", "Haiti" },
            { "HU", "Hungakalia" },
            { "IC", "\u02bbOtumotu Kaneli" },
            { "ID", "\u02bbIniton\u0113sia" },
            { "IE", "\u02bbAealani" },
            { "IL", "\u02bbIsileli" },
            { "IM", "Motu Mani" },
            { "IN", "\u02bbInitia" },
            { "IO", "Potu fonua moana \u02bbInitia fakapilit\u0101nia" },
            { "IQ", "\u02bbIlaaki" },
            { "IR", "\u02bbIlaani" },
            { "IS", "\u02bbAisilani" },
            { "IT", "\u02bb\u012atali" },
            { "JE", "Selus\u012b" },
            { "JM", "Samaika" },
            { "JO", "Soatane" },
            { "JP", "Siapani" },
            { "KE", "Keni\u0101" },
            { "KG", "K\u012bkisitani" },
            { "KH", "Kamip\u014dtia" },
            { "KI", "Kilipasi" },
            { "KM", "Komolosi" },
            { "KN", "S\u0101 Kitisi mo Nevisi" },
            { "KP", "K\u014dlea tokelau" },
            { "KR", "K\u014dlea tonga" },
            { "KW", "Kueiti" },
            { "KY", "\u02bbOtumotu Keimeni" },
            { "KZ", "Kasakitani" },
            { "LA", "Lau" },
            { "LB", "Lepanoni" },
            { "LC", "S\u0101 L\u016bsia" },
            { "LI", "Likitenisiteini" },
            { "LK", "S\u012blangik\u0101" },
            { "LR", "Laipelia" },
            { "LS", "Lesoto" },
            { "LT", "Lituania" },
            { "LU", "Lakisimipeki" },
            { "LV", "Lativia" },
            { "LY", "L\u012bpia" },
            { "MA", "Moloko" },
            { "MC", "Monako" },
            { "MD", "Molotova" },
            { "ME", "Monitenikalo" },
            { "MF", "S\u0101 M\u0101tini (fakafalanis\u0113)" },
            { "MG", "Matakasika" },
            { "MH", "\u02bbOtumotu M\u0101solo" },
            { "MK", "Maset\u014dnia" },
            { "ML", "M\u0101li" },
            { "MM", "Mianim\u0101 (Pema)" },
            { "MN", "Mongok\u014dlia" },
            { "MO", "Makau SAR Siaina" },
            { "MP", "\u02bbOtumotu Maliana tokelau" },
            { "MQ", "M\u0101tiniki" },
            { "MR", "Maulitenia" },
            { "MS", "Mo\u02bbungaselati" },
            { "MT", "Malita" },
            { "MU", "Maulitiusi" },
            { "MV", "Malativisi" },
            { "MW", "Malaui" },
            { "MX", "Mekisikou" },
            { "MY", "Mal\u0113sia" },
            { "MZ", "Mos\u0113mipiki" },
            { "NA", "Namipia" },
            { "NC", "Niu Kalet\u014dnia" },
            { "NE", "Nisia" },
            { "NF", "Motu N\u014dfoliki" },
            { "NG", "Naisilia" },
            { "NI", "Nikalakua" },
            { "NL", "H\u014dlani" },
            { "NO", "Noau\u0113" },
            { "NP", "Nepali" },
            { "NR", "Naulu" },
            { "NU", "Niu\u0113" },
            { "NZ", "Nu\u02bbusila" },
            { "OM", "\u02bbOmani" },
            { "PA", "Panam\u0101" },
            { "PE", "Pel\u016b" },
            { "PF", "Polinisia fakafalanis\u0113" },
            { "PG", "Papuaniukini" },
            { "PH", "Filipaini" },
            { "PK", "P\u0101kisitani" },
            { "PL", "Polani" },
            { "PM", "S\u0101 Piea mo Mikeloni" },
            { "PN", "\u02bbOtumotu Pitikeni" },
            { "PR", "Pu\u0113to Liko" },
            { "PS", "Potu Palesitaine" },
            { "PT", "Potukali" },
            { "PW", "Palau" },
            { "PY", "Palakuai" },
            { "QA", "Kat\u0101" },
            { "QO", "\u02bbOs\u0113nia mama\u02bbo" },
            { "RE", "L\u0113unioni" },
            { "RO", "Lom\u0113nia" },
            { "RS", "S\u0113pia" },
            { "RU", "L\u016bsia" },
            { "RW", "Luanit\u0101" },
            { "SA", "Saute \u02bbAlepea" },
            { "SB", "\u02bbOtumotu Solomone" },
            { "SC", "\u02bbOtumotu Seiseli" },
            { "SD", "S\u016bteni" },
            { "SE", "Su\u0113teni" },
            { "SG", "Singapoa" },
            { "SH", "S\u0101 Helena" },
            { "SI", "Sil\u014dvenia" },
            { "SJ", "Sivolop\u0101ti mo Sani Maieni" },
            { "SK", "Sil\u014dvakia" },
            { "SL", "Siela Leone" },
            { "SM", "S\u0101 Malino" },
            { "SN", "Senekalo" },
            { "SO", "S\u014dmalia" },
            { "SR", "Suliname" },
            { "SS", "S\u016btani fakatonga" },
            { "ST", "Sao Tom\u0113 mo Pilinisipe" },
            { "SV", "\u02bbEle Salavatoa" },
            { "SX", "S\u0101 M\u0101tini (fakah\u014dlani)" },
            { "SY", "S\u012blia" },
            { "SZ", "Suasilani" },
            { "TA", "Tulisitani ta Kunuha" },
            { "TC", "\u02bbOtumotu Tuki mo Kaikosi" },
            { "TD", "S\u0101ti" },
            { "TF", "Potu fonua tonga fakafalanis\u0113" },
            { "TG", "Toko" },
            { "TH", "Tailani" },
            { "TJ", "Tasikitani" },
            { "TK", "Tokelau" },
            { "TL", "Timoa hahake" },
            { "TM", "T\u016bkimenisitani" },
            { "TN", "Tun\u012bsia" },
            { "TO", "Tonga" },
            { "TR", "Toake" },
            { "TT", "Tilinitati mo Topako" },
            { "TV", "T\u016bvalu" },
            { "TW", "Taiuani" },
            { "TZ", "Tenis\u0101nia" },
            { "UA", "\u02bb\u016akala\u02bbine" },
            { "UG", "\u02bbIukanit\u0101" },
            { "UM", "\u02bbOtumotu si\u02bbi \u02bbo \u02bbAmelika" },
            { "UN", "\u02bb\u016a fonua fakatahataha" },
            { "US", "Pule\u02bbanga fakatahataha \u02bbAmelika" },
            { "UY", "\u02bbUlukuai" },
            { "UZ", "\u02bbUsipekitani" },
            { "VA", "Kolo Vatikani" },
            { "VC", "S\u0101 Viniseni mo Kulenatini" },
            { "VE", "Venesuela" },
            { "VG", "\u02bbOtumotu Vilikini fakapilit\u0101nia" },
            { "VI", "\u02bbOtumotu Vilikini faka\u02bbamelika" },
            { "VN", "Vietinami" },
            { "VU", "Vanuatu" },
            { "WF", "\u02bbUvea mo Futuna" },
            { "WS", "Ha\u02bbamoa" },
            { "XK", "K\u014dsovo" },
            { "YE", "Iemeni" },
            { "YT", "Maiote" },
            { "ZA", "\u02bbAfilika tonga" },
            { "ZM", "Semipia" },
            { "ZW", "Simipapuei" },
            { "ZZ", "Potu fonua ta\u02bbe\u02bbiloa pe hala" },
            { "aa", "lea faka\u02bbaf\u0101la" },
            { "ab", "lea faka\u02bbapakasia" },
            { "ae", "lea faka\u02bbavesitani" },
            { "af", "lea faka\u02bbafilikana" },
            { "ak", "lea faka\u02bbakani" },
            { "am", "lea faka\u02bbameliki" },
            { "an", "lea faka\u02bbalakoni" },
            { "ar", "lea faka\u02bbalepea" },
            { "as", "lea faka\u02bbasamia" },
            { "av", "lea faka\u02bbavaliki" },
            { "ay", "lea faka\u02bbaimala" },
            { "az", "lea faka\u02bbasapaisani" },
            { "ba", "lea fakapasikili" },
            { "be", "lea fakapelalusi" },
            { "bg", "lea fakapulukalia" },
            { "bi", "lea fakapisilama" },
            { "bm", "lea fakapamipala" },
            { "bn", "lea fakap\u0101ngil\u0101" },
            { "bo", "lea fakatipeti" },
            { "br", "lea fakapeletoni" },
            { "bs", "lea fakaposinia" },
            { "ca", "lea fakakatalani" },
            { "ce", "lea fakasese" },
            { "ch", "lea fakakamolo" },
            { "co", "lea fakak\u014dsika" },
            { "cr", "lea fakakel\u012b" },
            { "cs", "lea fakaseki" },
            { "cu", "lea fakasilavia-fakasiasi" },
            { "cv", "lea fakasuvasa" },
            { "cy", "lea fakau\u0113lesi" },
            { "da", "lea fakatenima\u02bbake" },
            { "de", "lea fakasiamane" },
            { "dv", "lea fakativehi" },
            { "dz", "lea fakatis\u014dngika" },
            { "ee", "lea faka\u02bbeue" },
            { "el", "lea fakakalisi" },
            { "en", "lea fakap\u0101langi" },
            { "eo", "lea faka\u02bbesipulanito" },
            { "es", "lea fakasip\u0113nisi" },
            { "et", "lea faka\u02bbesit\u014dnia" },
            { "eu", "lea fakap\u0101siki" },
            { "fa", "lea fakap\u0113sia" },
            { "ff", "lea fakaful\u0101" },
            { "fi", "lea fakafinilani" },
            { "fj", "lea fakafisi" },
            { "fo", "lea fakafaloe" },
            { "fr", "lea fakafalanis\u0113" },
            { "fy", "lea fakafilisia-hihifo" },
            { "ga", "lea faka\u02bbaelani" },
            { "gd", "lea fakakaeliki" },
            { "gl", "lea fakakalisia" },
            { "gn", "lea fakakualani" },
            { "gu", "lea fakakutalati" },
            { "gv", "lea fakamangik\u012b" },
            { "ha", "lea fakahausa" },
            { "he", "lea fakahepel\u016b" },
            { "hi", "lea fakahinit\u012b" },
            { "ho", "lea fakahili-motu" },
            { "hr", "lea fakakuloisia" },
            { "ht", "lea fakahaiti" },
            { "hu", "lea fakahungakalia" },
            { "hy", "lea faka\u02bb\u0101menia" },
            { "hz", "lea fakahelelo" },
            { "ia", "lea fakavaha\u02bbalea" },
            { "id", "lea faka\u02bbinit\u014dnesia" },
            { "ie", "lea fakavaha\u02bbalingik\u0113" },
            { "ig", "lea faka\u02bbikip\u014d" },
            { "ii", "lea fakasisiuani-\u012b" },
            { "ik", "lea faka\u02bbinupiaki" },
            { "io", "lea faka\u02bbito" },
            { "is", "lea faka\u02bbaisilani" },
            { "it", "lea faka\u02bb\u012btali" },
            { "iu", "lea faka\u02bbinuketituti" },
            { "ja", "lea fakasiapani" },
            { "jv", "lea fakasava" },
            { "ka", "lea fakase\u014dsia" },
            { "kg", "lea fakakongik\u014d" },
            { "ki", "lea fakakikuiu" },
            { "kj", "lea fakakuaniama" },
            { "kk", "lea fakakasaki" },
            { "kl", "lea fakakala\u02bbalisuti" },
            { "km", "lea fakakamip\u014dtia" },
            { "kn", "lea fakakanata" },
            { "ko", "lea fakak\u014dlea" },
            { "kr", "lea fakakanuli" },
            { "ks", "lea fakak\u0101simila" },
            { "ku", "lea fakakulit\u012b" },
            { "kv", "lea fakakomi" },
            { "kw", "lea fakakoniuali" },
            { "ky", "lea fakak\u012bsisi" },
            { "la", "lea fakalatina" },
            { "lb", "lea fakalakisimipeki" },
            { "lg", "lea fakakanita" },
            { "li", "lea fakalimip\u016bliki" },
            { "ln", "lea lingikala" },
            { "lo", "lea fakalau" },
            { "lt", "lea fakalituania" },
            { "lu", "lea fakalupa-katanga" },
            { "lv", "lea fakalativia" },
            { "mg", "lea fakamalakasi" },
            { "mh", "lea fakam\u0101solo" },
            { "mi", "lea fakamauli" },
            { "mk", "lea fakamasit\u014dnia" },
            { "ml", "lea faka\u02bbinitia-mal\u0101ialami" },
            { "mn", "lea fakamongok\u014dlia" },
            { "mr", "lea fakamalati" },
            { "ms", "lea fakamalei" },
            { "mt", "lea fakamalita" },
            { "my", "lea fakapema" },
            { "na", "lea fakanaulu" },
            { "nb", "lea fakanoua\u0113-pokimali" },
            { "nd", "lea fakanetepele-tokelau" },
            { "ne", "lea fakanepali" },
            { "ng", "lea fakanetongik\u0101" },
            { "nl", "lea fakah\u014dlani" },
            { "nn", "lea fakanoau\u0113-ninosiki" },
            { "no", "lea fakanoua\u0113" },
            { "nr", "lea fakanetepele-tonga" },
            { "nv", "lea fakanavaho" },
            { "ny", "lea fakanianisa" },
            { "oc", "lea faka\u02bbokitane" },
            { "oj", "lea faka\u02bbosipiu\u0101" },
            { "om", "lea faka\u02bbolomo" },
            { "or", "lea faka-\u02bbotia" },
            { "os", "lea faka\u02bbosetiki" },
            { "pa", "lea fakap\u016bnusapi" },
            { "pi", "lea fakap\u0101li" },
            { "pl", "lea fakapolani" },
            { "ps", "lea fakapasit\u014d" },
            { "pt", "lea fakapotukali" },
            { "qu", "lea fakakuetisa" },
            { "rm", "lea fakalaito-lom\u0113nia" },
            { "rn", "lea fakaluaniti" },
            { "ro", "lea fakal\u014dmenia" },
            { "ru", "lea fakal\u016bsia" },
            { "rw", "lea fakakini\u0101uanita" },
            { "sa", "lea fakasanisukuliti" },
            { "sc", "lea fakasalet\u012bnia" },
            { "sd", "lea fakas\u012bniti" },
            { "se", "lea fakasami-tokelau" },
            { "sg", "lea fakasangik\u014d" },
            { "sh", "lea fakakuloisia-s\u0113pia" },
            { "si", "lea fakasingihala" },
            { "sk", "lea fakasol\u0101vaki" },
            { "sl", "lea fakasolovenia" },
            { "sm", "lea fakaha\u02bbamoa" },
            { "sn", "lea fakasiona" },
            { "so", "lea fakasomali" },
            { "sq", "lea faka\u02bbalap\u0113nia" },
            { "sr", "lea fakas\u0113pia" },
            { "ss", "lea fakasuati" },
            { "st", "lea fakasoto-tonga" },
            { "su", "lea fakasunit\u0101" },
            { "sv", "lea fakasu\u0113teni" },
            { "sw", "lea fakasuahili" },
            { "ta", "lea fakatamili" },
            { "te", "lea faka\u02bbinitia-teluku" },
            { "tg", "lea fakat\u0101siki" },
            { "th", "lea fakatailani" },
            { "ti", "lea fakatikilinia" },
            { "tk", "lea fakat\u0113kimeni" },
            { "tl", "lea fakatak\u0101loka" },
            { "tn", "lea fakatisuana" },
            { "to", "lea fakatonga" },
            { "tr", "lea fakatoake" },
            { "ts", "lea fakatisonga" },
            { "tt", "lea fakatatale" },
            { "tw", "lea fakatusu\u012b" },
            { "ty", "lea fakatahiti" },
            { "ug", "lea faka\u02bbuik\u016bli" },
            { "uk", "lea faka\u02bb\u016bkala\u02bbine" },
            { "ur", "lea faka\u02bb\u016bt\u016b" },
            { "uz", "lea faka\u02bbusipeki" },
            { "ve", "lea fakavenit\u0101" },
            { "vi", "lea fakavietinami" },
            { "vo", "lea fakavolapiki" },
            { "wa", "lea faka\u02bbualonia" },
            { "wo", "lea faka\u02bbuolofo" },
            { "xh", "lea fakat\u014dsa" },
            { "yi", "lea faka\u012btisi" },
            { "yo", "lea faka\u02bbi\u014dlupa" },
            { "za", "lea fakasuangi" },
            { "zh", "lea fakasiaina" },
            { "zu", "lea fakasulu" },
            { "ace", "lea faka\u02bbatis\u0113" },
            { "ach", "lea faka\u02bbakoli" },
            { "ada", "lea faka\u02bbatangim\u0113" },
            { "ady", "lea faka\u02bbatik\u0113" },
            { "aeb", "lea faka\u02bbalepea-tun\u012bsia" },
            { "afh", "lea faka\u02bbafilihili" },
            { "agq", "lea faka\u02bbakihemi" },
            { "ain", "lea faka\u02bbainu" },
            { "akk", "lea faka\u02bbakatia" },
            { "akz", "lea faka\u02bbalapama" },
            { "ale", "lea faka\u02bbaleuti" },
            { "aln", "lea faka\u02bbalap\u0113nia-keki" },
            { "alt", "lea faka\u02bbalitai-tonga" },
            { "ang", "lea fakap\u0101langi-motu\u02bba" },
            { "anp", "lea faka\u02bbangika" },
            { "arc", "lea faka\u02bbal\u0101miti" },
            { "arn", "lea fakamapuse" },
            { "aro", "lea faka\u02bbalaona" },
            { "arp", "lea faka\u02bbalapaho" },
            { "arq", "lea faka\u02bbalepea-\u02bbaisilia" },
            { "arw", "lea faka\u02bbalauaki" },
            { "ary", "lea faka\u02bbalepea-moloko" },
            { "arz", "lea faka\u02bbalepea-\u02bbisipite" },
            { "asa", "lea faka\u02bbasu" },
            { "ase", "lea faka\u02bbilonga-\u02bbamelika" },
            { "ast", "lea faka\u02bbasit\u016blia" },
            { "avk", "lea fakakotava" },
            { "awa", "lea faka\u02bbauati" },
            { "bal", "lea fakapalusi" },
            { "ban", "lea fakapali" },
            { "bar", "lea fakapav\u0101lia" },
            { "bas", "lea fakapasa\u02bba" },
            { "bax", "lea fakapamuni" },
            { "bbc", "lea fakat\u014dpe-p\u0113teki" },
            { "bbj", "lea fakakomala" },
            { "bej", "lea fakapesa" },
            { "bem", "lea fakap\u0113mipa" },
            { "bew", "lea fakapetavi" },
            { "bez", "lea fakapena" },
            { "bfd", "lea fakapafuti" },
            { "bfq", "lea fakapataka" },
            { "bgn", "lea fakapalusi-hihifo" },
            { "bho", "lea fakaposipuli" },
            { "bik", "lea fakapikoli" },
            { "bin", "lea fakapini" },
            { "bjn", "lea fakapanisali" },
            { "bkm", "lea fakakome" },
            { "bla", "lea fakasikesik\u0101" },
            { "bpy", "lea fakapisinupilia" },
            { "bqi", "lea fakapakiti\u0101li" },
            { "bra", "lea fakapalai" },
            { "brh", "lea fakapalahui" },
            { "brx", "lea fakap\u014dto" },
            { "bss", "lea faka\u02bbak\u014dse" },
            { "bua", "lea fakapuliati" },
            { "bug", "lea fakapukisi" },
            { "bum", "lea fakapulu" },
            { "byn", "lea fakapilini" },
            { "byv", "lea fakamet\u016bmipa" },
            { "cad", "lea fakakato" },
            { "car", "lea fakakalipa" },
            { "cay", "lea fakakaiuka" },
            { "cch", "lea faka\u02bbatisami" },
            { "ceb", "lea fakasepuano" },
            { "cgg", "lea fakakika" },
            { "chb", "lea fakas\u012bpisa" },
            { "chg", "lea fakasakat\u0101i" },
            { "chk", "lea fakat\u016bke" },
            { "chm", "lea fakamal\u012b" },
            { "chn", "lea fakasinuki-takote" },
            { "cho", "lea fakasokitau" },
            { "chp", "lea fakasipeuiani" },
            { "chr", "lea fakaselok\u012b" },
            { "chy", "lea fakaseiene" },
            { "ckb", "lea fakak\u016btisi-loloto" },
            { "cop", "lea fakakopitika" },
            { "cps", "lea fakakapiseno" },
            { "crh", "lea fakatoake-kilimea" },
            { "crs", "lea fakaseselua-falanis\u0113" },
            { "csb", "lea fakakasiupia" },
            { "dak", "lea fakatakota" },
            { "dar", "lea fakatalaku\u0101" },
            { "dav", "lea fakataita" },
            { "del", "lea fakatelauale" },
            { "den", "lea fakasilave" },
            { "dgr", "lea fakat\u014dkelipi" },
            { "din", "lea fakatingik\u0101" },
            { "dje", "lea fakatis\u0101ma" },
            { "doi", "lea fakatokili" },
            { "dsb", "lea fakas\u014dpia-hifo" },
            { "dtp", "lea fakatusuni-loloto" },
            { "dua", "lea fakatuala" },
            { "dum", "lea fakah\u014dlani-lotoloto" },
            { "dyo", "lea fakaiola-fon\u012b" },
            { "dyu", "lea fakatiula" },
            { "dzg", "lea fakatasaka" },
            { "ebu", "lea faka\u02bbemip\u016b" },
            { "efi", "lea faka\u02bbefiki" },
            { "egl", "lea faka\u02bbemilia" },
            { "egy", "lea faka\u02bbisipitemu\u02bba" },
            { "eka", "lea faka\u02bbekaiuki" },
            { "elx", "lea faka\u02bbelamite" },
            { "enm", "lea fakap\u0101langi-lotoloto" },
            { "esu", "lea fakai\u016bpiki-loloto" },
            { "ewo", "lea faka\u02bbeu\u014dnito" },
            { "ext", "lea faka\u02bbekisitematula" },
            { "fan", "lea fakafangi" },
            { "fat", "lea fakafanit\u0113" },
            { "fil", "lea fakafilipaini" },
            { "fit", "lea fakafinilani-t\u014dnetale" },
            { "fon", "lea fakaf\u014dngi" },
            { "frc", "lea fakafalanis\u0113-kasuni" },
            { "frm", "lea fakafalanis\u0113-lotoloto" },
            { "fro", "lea fakafalanis\u0113-motu\u02bba" },
            { "frp", "lea faka\u02bb\u0101pitano" },
            { "frr", "lea fakafilisia-tokelau" },
            { "frs", "lea fakafilisia-hahake" },
            { "fur", "lea fakafulil\u0101ni" },
            { "gaa", "lea fakak\u0101" },
            { "gag", "lea fakakakausi" },
            { "gan", "lea fakasiaina-kani" },
            { "gay", "lea fakakaio" },
            { "gba", "lea fakakapaia" },
            { "gbz", "lea fakateli-soloasitelia" },
            { "gez", "lea fakasi\u02bbisi" },
            { "gil", "lea fakakilipasi" },
            { "glk", "lea fakakilaki" },
            { "gmh", "lea fakasiamane-hake-lotoloto" },
            { "goh", "lea fakasiamane-hake-motu\u02bba" },
            { "gom", "lea fakakonikan\u012b-koani" },
            { "gon", "lea fakakonit\u012b" },
            { "gor", "lea fakakolonitalo" },
            { "got", "lea fakakotika" },
            { "grb", "lea fakak\u0113po" },
            { "grc", "lea fakakalisimu\u02bba" },
            { "gsw", "lea fakasiamane-suisilani" },
            { "guc", "lea faka\u02bbuai\u016b" },
            { "gur", "lea fakafalefale" },
            { "guz", "lea fakakus\u012b" },
            { "gwi", "lea faka\u02bbu\u012bsini" },
            { "hai", "lea fakahaita" },
            { "hak", "lea fakasiaina-haka" },
            { "haw", "lea fakahauai\u02bbi" },
            { "hif", "lea fakahinit\u012b-fisi" },
            { "hil", "lea fakahilikainoni" },
            { "hit", "lea fakahitite" },
            { "hmn", "lea fakam\u014dngi" },
            { "hsb", "lea fakas\u014dpia-hake" },
            { "hsn", "lea fakasiaina-siangi" },
            { "hup", "lea fakahupa" },
            { "iba", "lea faka\u02bbipani" },
            { "ibb", "lea faka\u02bbipipio" },
            { "ilo", "lea faka\u02bbiloko" },
            { "inh", "lea faka\u02bbingusi" },
            { "izh", "lea faka\u02bbingiliani" },
            { "jam", "lea fakap\u0101langi-samaika" },
            { "jbo", "lea fakalosipani" },
            { "jgo", "lea fakanik\u014dmipa" },
            { "jmc", "lea fakamasame" },
            { "jpr", "lea faka\u02bbiuteo-p\u0113sia" },
            { "jrb", "lea faka\u02bbiuteo-\u02bbalepea" },
            { "jut", "lea faka\u02bbiutilani" },
            { "kaa", "lea fakakala-kalipaki" },
            { "kab", "lea fakakapile" },
            { "kac", "lea fakakasini" },
            { "kaj", "lea fakasis\u016b" },
            { "kam", "lea fakakamipa" },
            { "kaw", "lea fakakavi" },
            { "kbd", "lea fakakap\u0101litia" },
            { "kbl", "lea fakakan\u0113mipu" },
            { "kcg", "lea fakatiapi" },
            { "kde", "lea fakamak\u014dnite" },
            { "kea", "lea fakakapuvelitianu" },
            { "ken", "lea fakakeniangi" },
            { "kfo", "lea fakakolo" },
            { "kgp", "lea fakakaingangi" },
            { "kha", "lea fakak\u0101si" },
            { "kho", "lea fakak\u014dtani" },
            { "khq", "lea fakakoila-s\u012bni" },
            { "khw", "lea fakakouali" },
            { "kiu", "lea fakakilimanisik\u012b" },
            { "kkj", "lea fakakako" },
            { "kln", "lea fakakalenisini" },
            { "kmb", "lea fakakimip\u016bnitu" },
            { "koi", "lea fakakomi-pelemiaki" },
            { "kok", "lea fakakonikan\u012b" },
            { "kos", "lea fakakosilae" },
            { "kpe", "lea fakakepele" },
            { "krc", "lea fakakalate-palakili" },
            { "kri", "lea fakakilio" },
            { "krj", "lea fakakinarai\u0101" },
            { "krl", "lea fakakalelia" },
            { "kru", "lea fakakuluki" },
            { "ksb", "lea fakasiamipala" },
            { "ksf", "lea fakapafia" },
            { "ksh", "lea fakakolongia" },
            { "kum", "lea fakakumiki" },
            { "kut", "lea fakakutenai" },
            { "lad", "lea fakalatino" },
            { "lag", "lea fakalangi" },
            { "lah", "lea fakal\u0101nita" },
            { "lam", "lea fakalamip\u0101" },
            { "lez", "lea fakalesikia" },
            { "lfn", "lea fakakavakava-fo\u02bbou" },
            { "lij", "lea fakalikulia" },
            { "liv", "lea fakalivonia" },
            { "lkt", "lea fakalakota" },
            { "lmo", "lea fakalomip\u0101ti" },
            { "lol", "lea fakamongik\u014d" },
            { "loz", "lea fakalosi" },
            { "lrc", "lea fakaluli-tokelau" },
            { "ltg", "lea fakalatakale" },
            { "lua", "lea fakalupa-lulua" },
            { "lui", "lea fakaluiseno" },
            { "lun", "lea fakalunit\u0101" },
            { "luo", "lea fakaluo" },
            { "lus", "lea fakamiso" },
            { "luy", "lea fakalu\u012ba" },
            { "lzh", "lea fakasiaina-fa\u02bbutohi" },
            { "lzz", "lea fakalasu" },
            { "mad", "lea fakamatula" },
            { "maf", "lea fakamafa" },
            { "mag", "lea fakamakahi" },
            { "mai", "lea fakamaitili" },
            { "mak", "lea fakamakasali" },
            { "man", "lea fakamanit\u012bngiko" },
            { "mas", "lea fakamasai" },
            { "mde", "lea fakamapa" },
            { "mdf", "lea fakamokisi\u0101" },
            { "mdr", "lea fakamanetali" },
            { "men", "lea fakamenet\u012b" },
            { "mer", "lea fakamelu" },
            { "mfe", "lea fakamolisieni" },
            { "mga", "lea faka\u02bbaelani-lotoloto" },
            { "mgh", "lea fakamak\u016ba-me\u02bbeto" },
            { "mgo", "lea fakamet\u0101" },
            { "mic", "lea fakamikemaki" },
            { "min", "lea fakaminangikapau" },
            { "mnc", "lea fakamanis\u016b" },
            { "mni", "lea fakamanipuli" },
            { "moh", "lea fakamohauki" },
            { "mos", "lea fakamosi" },
            { "mrj", "lea fakamali-hihifo" },
            { "mua", "lea fakamunitangi" },
            { "mul", "lea tuifio" },
            { "mus", "lea fakakileki" },
            { "mwl", "lea fakamilanit\u0113si" },
            { "mwr", "lea fakamaliwali" },
            { "mwv", "lea fakamenitauai" },
            { "mye", "lea fakamiene" },
            { "myv", "lea faka\u02bbelisia" },
            { "mzn", "lea fakamasanitelani" },
            { "nan", "lea fakasiaina-mininani" },
            { "nap", "lea fakanapoletano" },
            { "naq", "lea fakanama" },
            { "nds", "lea fakasiamane-hifo" },
            { "new", "lea fakaneuali" },
            { "nia", "lea fakaniasi" },
            { "niu", "lea fakaniu\u0113" },
            { "njo", "lea faka\u02bbaonasa" },
            { "nmg", "lea fakakuasio" },
            { "nnh", "lea fakangiemip\u014dni" },
            { "nog", "lea fakanokai" },
            { "non", "lea fakanoau\u0113-motu\u02bba" },
            { "nov", "lea fakanoviale" },
            { "nqo", "lea fakanik\u014d" },
            { "nso", "lea fakasoto-tokelau" },
            { "nus", "lea fakanueli" },
            { "nwc", "lea fakaneuali-motu\u02bba" },
            { "nym", "lea fakaniamiuesi" },
            { "nyn", "lea fakanianikole" },
            { "nyo", "lea fakaniolo" },
            { "nzi", "lea fakanesima" },
            { "osa", "lea faka\u02bbos\u0113se" },
            { "ota", "lea fakatoake-\u02bbotomani" },
            { "pag", "lea fakapangasinani" },
            { "pal", "lea fakap\u0101lavi" },
            { "pam", "lea fakapamipanga" },
            { "pap", "lea fakapapiam\u0113nito" },
            { "pau", "lea fakapalau" },
            { "pcd", "lea fakapik\u0101ti" },
            { "pcm", "lea fakanaisilia" },
            { "pdc", "lea fakasiamane-penisilivania" },
            { "pdt", "lea fakasiamane-lafalafa" },
            { "peo", "lea fakap\u0113sia-motu\u02bba" },
            { "pfl", "lea fakasiamane-palatine" },
            { "phn", "lea fakafoinikia" },
            { "pms", "lea fakapiemonite" },
            { "pnt", "lea fakaponitiki" },
            { "pon", "lea fakaponap\u0113" },
            { "prg", "lea fakapul\u016bsia" },
            { "pro", "lea fakapolovenisi-motu\u02bba" },
            { "quc", "lea fakak\u012bs\u0113" },
            { "qug", "lea fakakuitisa-simipolaso" },
            { "raj", "lea fakalasasitani" },
            { "rap", "lea fakalapanui" },
            { "rar", "lea fakalalotonga" },
            { "rgn", "lea fakalomaniolo" },
            { "rif", "lea fakalifi" },
            { "rof", "lea fakalomip\u014d" },
            { "rom", "lea fakalomani" },
            { "rtm", "lea fakalotuma" },
            { "rue", "lea fakalusini" },
            { "rug", "lea fakaloviana" },
            { "rup", "lea faka\u02bbalomania" },
            { "rwk", "lea fakalu\u0101" },
            { "sad", "lea fakasanitaue" },
            { "sah", "lea fakasaka" },
            { "sam", "lea fakasamalitani-\u02bbal\u0101miti" },
            { "saq", "lea fakasamipulu" },
            { "sas", "lea fakasasaki" },
            { "sat", "lea fakasanitali" },
            { "saz", "lea fakasaulasitil\u0101" },
            { "sba", "lea fakang\u0101mipai" },
            { "sbp", "lea fakasangu" },
            { "scn", "lea fakasis\u012blia" },
            { "sco", "lea fakasikotilani" },
            { "sdc", "lea fakasalet\u012bnia-sasalesu" },
            { "sdh", "lea faka-tonga \u2018o Ketesi" },
            { "see", "lea fakaseneka" },
            { "seh", "lea fakasena" },
            { "sei", "lea fakaseli" },
            { "sel", "lea fakaselikupi" },
            { "ses", "lea fakakoilapolo-seni" },
            { "sga", "lea faka\u02bbaelani-motu\u02bba" },
            { "sgs", "lea fakasamositia" },
            { "shi", "lea fakataselihiti" },
            { "shn", "lea fakasiani" },
            { "shu", "lea faka\u02bbalepea-s\u0101ti" },
            { "sid", "lea fakasitamo" },
            { "sli", "lea fakasilesia-hifo" },
            { "sly", "lea fakaselai\u0101" },
            { "sma", "lea fakasami-tonga" },
            { "smj", "lea fakasami-lule" },
            { "smn", "lea fakasami-\u02bbinali" },
            { "sms", "lea fakasami-sikolita" },
            { "snk", "lea fakasoninek\u0113" },
            { "sog", "lea fakasokitiana" },
            { "srn", "lea fakasulanane-tongik\u014d" },
            { "srr", "lea fakas\u0113l\u0113le" },
            { "ssy", "lea fakasaho" },
            { "stq", "lea fakafilisia-sat\u0113lani" },
            { "suk", "lea fakasukuma" },
            { "sus", "lea fakasus\u016b" },
            { "sux", "lea fakasumelia" },
            { "swb", "lea fakakomolo" },
            { "syc", "lea fakasuli\u0101i\u0101-mu\u02bba" },
            { "syr", "lea fakasuli\u0101i\u0101" },
            { "szl", "lea fakasilesia" },
            { "tcy", "lea fakatulu" },
            { "tem", "lea fakatimen\u0113" },
            { "teo", "lea fakateso" },
            { "ter", "lea fakateleno" },
            { "tet", "lea fakatetumu" },
            { "tig", "lea fakatikil\u0113" },
            { "tiv", "lea fakativi" },
            { "tkl", "lea fakatokelau" },
            { "tkr", "lea fakas\u0101kuli" },
            { "tlh", "lea fakakilingoni" },
            { "tli", "lea fakatilingik\u012bte" },
            { "tly", "lea fakatalisi" },
            { "tmh", "lea fakatamasieki" },
            { "tog", "lea fakaniasa-tonga" },
            { "tpi", "lea fakatoki-pisini" },
            { "tru", "lea fakatuloio" },
            { "trv", "lea fakataloko" },
            { "tsd", "lea fakasak\u014dnia" },
            { "tsi", "lea fakatis\u012bmisiani" },
            { "ttt", "lea fakatati-moselemi" },
            { "tum", "lea fakatumepuka" },
            { "tvl", "lea fakat\u016bvalu" },
            { "twq", "lea fakatasauaki" },
            { "tyv", "lea fakatuv\u012bnia" },
            { "tzm", "lea fakatamasaiti-\u02bbatilasi-loloto" },
            { "udm", "lea faka\u02bbutimuliti" },
            { "uga", "lea faka\u02bb\u016bkaliti" },
            { "umb", "lea faka\u02bbumip\u016bnitu" },
            { "und", "lea ta\u02bbe\u02bbiloa" },
            { "vai", "lea fakavai" },
            { "vec", "lea fakaven\u0113sia" },
            { "vep", "lea fakavepisi" },
            { "vls", "lea fakavelamingi-hihifo" },
            { "vmf", "lea fakafalanikoni-loloto" },
            { "vot", "lea fakavotiki" },
            { "vro", "lea fakav\u014dlo" },
            { "vun", "lea fakav\u016bniso" },
            { "wae", "lea faka\u02bbualiseli" },
            { "wal", "lea faka\u02bbuolaita" },
            { "war", "lea faka\u02bbualai" },
            { "was", "lea faka\u02bbuasi\u014d" },
            { "wbp", "lea faka\u02bbu\u0101lipili" },
            { "wuu", "lea fakasiaina-u\u016b" },
            { "xal", "lea fakakalimiki" },
            { "xmf", "lea fakamingilelia" },
            { "xog", "lea fakasoka" },
            { "yao", "lea faka\u02bbiao" },
            { "yap", "lea faka\u02bbiapi" },
            { "yav", "lea faka\u02bbiangipeni" },
            { "ybb", "lea faka\u02bbi\u0113mipa" },
            { "yrl", "lea fakane\u02bb\u0113ngat\u016b" },
            { "yue", "lea fakakuangitongi" },
            { "zap", "lea fakasapoteki" },
            { "zbl", "lea faka\u02bbilonga-pilisi" },
            { "zea", "lea fakas\u0113lani" },
            { "zen", "lea fakasenaka" },
            { "zgh", "lea fakatamasaiti-moloko" },
            { "zun", "lea fakasuni" },
            { "zxx", "\u02bbikai ha lea" },
            { "zza", "lea fakas\u0101s\u0101" },
            { "Afak", "tohinima faka\u02bbafaka" },
            { "Aghb", "tohinima faka\u02bbalap\u0113nia-kaukasia" },
            { "Arab", "tohinima faka\u02bbalepea" },
            { "Armi", "tohinima faka\u02bbal\u0101miti-\u02bbemipaea" },
            { "Armn", "tohinima faka\u02bb\u0101menia" },
            { "Avst", "tohinima faka\u02bbavesitani" },
            { "Bali", "tohinima fakapali" },
            { "Bamu", "tohinima fakapamumi" },
            { "Bass", "tohinima fakapasa-v\u0101" },
            { "Batk", "tohinima fakap\u0101taki" },
            { "Beng", "tohinima fakap\u0101ngil\u0101" },
            { "Blis", "tohinima faka\u02bbilonga-pilisi" },
            { "Bopo", "tohinima fakapopomofo" },
            { "Brah", "tohinima fakapal\u0101m\u012b" },
            { "Brai", "tohinima laukonga ki he kui" },
            { "Bugi", "tohinima fakapukisi" },
            { "Buhd", "tohinima fakapuhiti" },
            { "Cakm", "tohinima fakasakim\u0101" },
            { "Cans", "tohinima fakatupu\u02bbi-k\u0101nata-fakatahataha" },
            { "Cari", "tohinima fakakali" },
            { "Cham", "tohinima fakasami" },
            { "Cher", "tohinima fakaselok\u012b" },
            { "Cirt", "tohinima fakak\u012bliti" },
            { "Copt", "tohinima fakakopitika" },
            { "Cprt", "tohinima fakasaipalesi" },
            { "Cyrl", "tohinima fakal\u016bsia" },
            { "Cyrs", "tohinima fakal\u016bsia-lotu-motu\u02bba" },
            { "Deva", "tohinima faka\u02bbinitia-tevan\u0101kal\u012b" },
            { "Dsrt", "tohinima fakateseleti" },
            { "Dupl", "tohinimanounou fakatupoloi\u0113" },
            { "Egyd", "tohinima temotika-faka\u02bbisipite" },
            { "Egyh", "tohinima hielatika-faka\u02bbisipite" },
            { "Egyp", "tohinima tongitapu-faka\u02bbisipite" },
            { "Elba", "tohinima faka\u02bbelepasani" },
            { "Ethi", "tohinima faka\u02bb\u012bti\u014dpia" },
            { "Geok", "tohinima fakakutusuli-se\u014dsia" },
            { "Geor", "tohinima fakase\u014dsia" },
            { "Glag", "tohinima fakakalakoliti" },
            { "Goth", "tohinima fakakotika" },
            { "Gran", "tohinima fakasilanit\u0101" },
            { "Grek", "tohinima fakakalisi" },
            { "Gujr", "tohinima faka\u02bbinitia-kutalati" },
            { "Guru", "tohinima fakak\u016bmuki" },
            { "Hanb", "tohinima fakah\u0101nipi" },
            { "Hang", "tohinima fakak\u014dlea-h\u0101ng\u016blu" },
            { "Hani", "tohinima fakasiaina" },
            { "Hano", "tohinima fakahanun\u014d\u02bbo" },
            { "Hans", "tohinima fakasiaina-fakafaingofua" },
            { "Hant", "tohinima fakasiaina-tukufakaholo" },
            { "Hebr", "tohinima fakahepel\u016b" },
            { "Hira", "tohinima fakasiapani-hilakana" },
            { "Hluw", "tohinima tongitapu-faka\u02bbanatolia" },
            { "Hmng", "tohinima fakapahaumongi" },
            { "Hrkt", "tohinima fakasilapa-siapani" },
            { "Hung", "tohinima fakahungakalia-motu\u02bba" },
            { "Inds", "tohinima faka\u02bbinitusi" },
            { "Ital", "tohinima faka\u02bb\u012btali-motu\u02bba" },
            { "Jamo", "tohinima fakasamo" },
            { "Java", "tohinima fakasava" },
            { "Jpan", "tohinima fakasiapani" },
            { "Jurc", "tohinima fakai\u016bkeni" },
            { "Kali", "tohinima fakakaial\u012b" },
            { "Kana", "tohinima fakasiapani-katakana" },
            { "Khar", "tohinima fakakalosit\u012b" },
            { "Khmr", "tohinima fakakamip\u014dtia" },
            { "Khoj", "tohinima fakakosik\u012b" },
            { "Knda", "tohinima faka\u02bbinitia-kanata" },
            { "Kore", "tohinima fakak\u014dlea" },
            { "Kpel", "tohinima fakakepele" },
            { "Kthi", "tohinima fakakaiat\u012b" },
            { "Lana", "tohinima fakalana" },
            { "Laoo", "tohinima fakalau" },
            { "Latf", "tohinima fakalatina-falakituli" },
            { "Latg", "tohinima fakalatina-kaeliki" },
            { "Latn", "tohinima fakalatina" },
            { "Lepc", "tohinima fakalepas\u0101" },
            { "Limb", "tohinima fakalimip\u016b" },
            { "Lina", "tohinima fakalinea-A" },
            { "Linb", "tohinima fakalinea-P" },
            { "Lisu", "tohinima fakafal\u0101se" },
            { "Loma", "tohinima fakaloma" },
            { "Lyci", "tohinima fakal\u012bsia" },
            { "Lydi", "tohinima fakal\u012btia" },
            { "Mahj", "tohinima fakamahasani" },
            { "Mand", "tohinima fakamanitaea" },
            { "Mani", "tohinima fakamanikaea" },
            { "Maya", "tohinima tongitapu fakamaia" },
            { "Mend", "tohinima fakam\u0113niti" },
            { "Merc", "tohinima fakameloue-heihei" },
            { "Mero", "tohinima fakameloue" },
            { "Mlym", "tohinima faka\u02bbinitia-mal\u0101ialami" },
            { "Modi", "tohinima fakamot\u012b" },
            { "Mong", "tohinima fakamongok\u014dlia" },
            { "Moon", "tohinima laukonga ki he kui-m\u0101hina" },
            { "Mroo", "tohinima fakamol\u014d" },
            { "Mtei", "tohinima fakametei-maieki" },
            { "Mymr", "tohinima fakapema" },
            { "Narb", "tohinima faka\u02bbalepea-tokelau-motu\u02bba" },
            { "Nbat", "tohinima fakanapatea" },
            { "Nkgb", "tohinima fakanati-sepa" },
            { "Nkoo", "tohinima fakanik\u014d" },
            { "Nshu", "tohinima fakanasi\u016b" },
            { "Ogam", "tohinima faka\u02bbokami" },
            { "Olck", "tohinima faka\u02bbolisiki" },
            { "Orkh", "tohinima faka\u02bbolikoni" },
            { "Orya", "tohinima faka\u02bbotia" },
            { "Osma", "tohinima faka\u02bbosim\u0101nia" },
            { "Palm", "tohinima fakapalamilene" },
            { "Pauc", "tohinima fakapausinihau" },
            { "Perm", "tohinima fakap\u0113mi-motu\u02bba" },
            { "Phag", "tohinima fakap\u0101kisip\u0101" },
            { "Phli", "tohinima fakap\u0101lavi-tongi" },
            { "Phlp", "tohinima fakap\u0101lavi-saame" },
            { "Phlv", "tohinima fakap\u0101lavi-tohi" },
            { "Phnx", "tohinima fakafoinikia" },
            { "Plrd", "tohinima fakafon\u0113tiki-pol\u0101ti" },
            { "Prti", "tohinima fakap\u0101tia-tongi" },
            { "Rjng", "tohinima fakalesiangi" },
            { "Roro", "tohinima fakalongolongo" },
            { "Runr", "tohinima fakaluniki" },
            { "Samr", "tohinima fakasamalitane" },
            { "Sara", "tohinima fakasalati" },
            { "Sarb", "tohinima faka\u02bbalepea-tonga-motu\u02bba" },
            { "Saur", "tohinima fakasaulasit\u0101" },
            { "Sgnw", "tohinima faka\u02bbilonga-tohi" },
            { "Shaw", "tohinima fakasiavi" },
            { "Shrd", "tohinima fakasi\u0101lat\u0101" },
            { "Sidd", "tohinima fakasititami" },
            { "Sind", "tohinima fakakutau\u0101ti" },
            { "Sinh", "tohinima fakasingihala" },
            { "Sora", "tohinima fakasolasomipengi" },
            { "Sund", "tohinima fakasunit\u0101" },
            { "Sylo", "tohinima fakasailoti-nakili" },
            { "Syrc", "tohinima fakasuli\u0101i\u0101" },
            { "Syre", "tohinima fakasuli\u0101i\u0101-\u02bbesitelangelo" },
            { "Syrj", "tohinima fakasuli\u0101i\u0101-hihifo" },
            { "Syrn", "tohinima fakasuli\u0101i\u0101-hahake" },
            { "Tagb", "tohinima fakatakipaneu\u0101" },
            { "Takr", "tohinima fakatakili" },
            { "Tale", "tohinima fakatai-lue" },
            { "Talu", "tohinima fakatai-lue-fo\u02bbou" },
            { "Taml", "tohinima fakatamili" },
            { "Tang", "tohinima fakatanguti" },
            { "Tavt", "tohinima fakatai-vieti" },
            { "Telu", "tohinima faka\u02bbinitia-teluku" },
            { "Teng", "tohinima fakatengiuali" },
            { "Tfng", "tohinima fakatifin\u0101ki" },
            { "Tglg", "tohinima fakatakaloka" },
            { "Thaa", "tohinima fakat\u0101na" },
            { "Thai", "tohinima fakatailani" },
            { "Tibt", "tohinima fakataipeti" },
            { "Tirh", "tohinima fakat\u012bhuta" },
            { "Ugar", "tohinima faka\u02bb\u016bkaliti" },
            { "Vaii", "tohinima fakavai" },
            { "Visp", "tohinima fakafon\u0113tiki-h\u0101mai" },
            { "Wara", "tohinima fakavalangi-kisit\u012b" },
            { "Wole", "tohinima fakauoleai" },
            { "Xpeo", "tohinima fakap\u0113siamu\u02bba" },
            { "Xsux", "tohinima fakamata\u02bbingahau-sumelo-akatia" },
            { "Yiii", "tohinima faka\u012b\u012b" },
            { "Zinh", "tohinima hokosi" },
            { "Zmth", "tohinima fakamatematika" },
            { "Zsye", "tohinima fakat\u0101t\u0101" },
            { "Zsym", "tohinima faka\u02bbilonga" },
            { "Zxxx", "tohinima ta\u02bbetohitohi\u02bbi" },
            { "Zyyy", "tohinima fakatatau" },
            { "Zzzz", "tohinima ta\u02bbe\u02bbiloa" },
            { "root", "lea faka\u02bbilonga-tefito" },
            { "de_AT", "lea fakasiamane-\u02bbaositulia" },
            { "de_CH", "lea fakasiamane-hake-suisilani" },
            { "en_AU", "lea fakap\u0101langi-\u02bbaositel\u0113lia" },
            { "en_CA", "lea fakap\u0101langi-k\u0101nata" },
            { "en_GB", "lea fakapilit\u0101nia" },
            { "en_US", "lea fakap\u0101langi-\u02bbamelika" },
            { "es_ES", "lea fakasip\u0113nisi-\u2018iulope" },
            { "es_MX", "lea fakasip\u0113nisi-mekisikou" },
            { "fr_CA", "lea fakafalanis\u0113-k\u0101nata" },
            { "fr_CH", "lea fakafalanis\u0113-suisilani" },
            { "nl_BE", "lea fakah\u014dlani-pelesiume" },
            { "pt_BR", "lea fakapotukali-pal\u0101sili" },
            { "pt_PT", "lea fakapotukali-\u02bbiulope" },
            { "ro_MD", "lea fakamolit\u0101via" },
            { "sw_CD", "lea fakasuahili-kongik\u014d" },
            { "ar_001", "lea faka\u02bbalepea (m\u0101mani)" },
            { "es_419", "lea fakasip\u0113nisi l\u0101tini-\u02bbamelika" },
            { "key.ca", "tohi m\u0101hina" },
            { "key.cf", "anga pa\u02bbanga" },
            { "key.co", "tohi hokohoko" },
            { "key.cu", "pa\u02bbanga" },
            { "key.hc", "takai houa" },
            { "key.lb", "fesi\u02bbilaine" },
            { "key.ms", "founga fakafuofua" },
            { "key.nu", "fika" },
            { "nds_NL", "lea fakasakisoni-hifo" },
            { "zh_Hans", "lea fakasiaina-fakafaingofua" },
            { "zh_Hant", "lea fakasiaina-tukufakaholo" },
            { "type.ca.roc", "fakalepupelika siaina" },
            { "type.hc.h11", "takai houa 0\u201311" },
            { "type.hc.h12", "takai houa 1\u201312" },
            { "type.hc.h23", "takai houa 0\u201323" },
            { "type.hc.h24", "takai houa 1\u201324" },
            { "type.nu.arab", "fika faka\u02bbalepea" },
            { "type.nu.armn", "fika faka\u02bb\u0101menia" },
            { "type.nu.beng", "faka fakap\u0101ngil\u0101" },
            { "type.nu.deva", "fika fakatevan\u0101kal\u012b" },
            { "type.nu.ethi", "fika faka\u02bb\u012bti\u014dpia" },
            { "type.nu.geor", "fika fakase\u014dsia" },
            { "type.nu.grek", "fika fakakalisi" },
            { "type.nu.gujr", "fika fakakutalati" },
            { "type.nu.guru", "fika fakak\u016bmuki" },
            { "type.nu.hans", "fika fakasiaina fakafaingofua" },
            { "type.nu.hant", "fika fakasiaina tukufakaholo" },
            { "type.nu.hebr", "fika fakahepel\u016b" },
            { "type.nu.jpan", "fika fakasiapani" },
            { "type.nu.khmr", "fika fakakamip\u014dtia" },
            { "type.nu.knda", "fika fakakanata" },
            { "type.nu.laoo", "fika fakalau" },
            { "type.nu.latn", "fika fakalatina" },
            { "type.nu.mlym", "fika fakamal\u0101ialami" },
            { "type.nu.mymr", "fika fakapema" },
            { "type.nu.nkoo", "fika fakanik\u014d" },
            { "type.nu.orya", "fika faka\u02bbotia" },
            { "type.nu.taml", "fika fakatamili tukufakaholo" },
            { "type.nu.telu", "fika fakateluku" },
            { "type.nu.thai", "fika fakatailani" },
            { "type.nu.tibt", "fika fakatipeti" },
            { "type.ca.dangi", "fakataniki" },
            { "type.co.ducet", "\u02bbunik\u014dti" },
            { "type.lb.loose", "fesi\u02bbilaine ngaloku" },
            { "type.nu.roman", "fika fakaloma" },
            { "type.ca.hebrew", "fakahepel\u016b" },
            { "type.ca.indian", "faka\u02bbinitia" },
            { "type.co.search", "fakakumi \u02bbi hono anga lahi" },
            { "type.lb.normal", "fesi\u02bbilaine fa\u02bbafai" },
            { "type.lb.strict", "fesi\u02bbilaine mafao" },
            { "type.ms.metric", "founga fakamita" },
            { "type.ca.chinese", "fakasiaina" },
            { "type.ca.islamic", "fakamohameti" },
            { "type.ca.iso8601", "faka-iso8601" },
            { "type.ca.persian", "fakap\u0113sia" },
            { "type.cf.account", "anga pa\u02bbanga-kalake" },
            { "type.nu.arabext", "fika faka\u02bbalepea fakalahi" },
            { "type.nu.armnlow", "fika faka\u02bb\u0101menia fakalalo" },
            { "type.nu.greklow", "fika fakakalisi fakalalo" },
            { "type.nu.hanidec", "fika fakasiaina" },
            { "type.nu.hansfin", "fika fakasiaina fakafaingofua fakapa\u02bbanga" },
            { "type.nu.hantfin", "fika fakasiaina tukufakaholo fakapa\u02bbanga" },
            { "type.nu.jpanfin", "fika fakasiapani fakapa\u02bbanga" },
            { "type.nu.tamldec", "fika fakatamili" },
            { "type.ca.buddhist", "fakaputa" },
            { "type.ca.ethiopic", "faka\u02bb\u012bti\u014dpia" },
            { "type.ca.japanese", "fakasiapani" },
            { "type.cf.standard", "anga pa\u02bbanga-s\u012bpinga" },
            { "type.co.standard", "fakas\u012bpinga" },
            { "type.ms.uksystem", "founga fakapilit\u0101nia" },
            { "type.ms.ussystem", "founga faka\u02bbamelika" },
            { "type.nu.fullwide", "fika laulahi" },
            { "type.nu.romanlow", "fika fakaloma fakalalo" },
            { "type.ca.gregorian", "fakakelekolia" },
            { "type.co.phonebook", "fika telefoni" },
            { "type.co.traditional", "tukufakaholo" },
            { "type.ca.islamic-civil", "fakamohameti-sivile" },
        };
        return data;
    }
}
